@@ -35,9 +35,6 @@
 /* Define to empty if the keyword does not work.  */
 #undef const
 
-/* Define to empty if the volatile keyword does not work.  */
-#undef volatile
-
 /* Define to one of _getb67, GETB67, getb67 for Cray-2 and Cray-YMP systems.
    This function is required for alloca.c support on those systems.  */
 #undef CRAY_STACKSEG_END
@@ -153,6 +150,9 @@
 /* Define if on MINIX.  */
 #undef _MINIX
 
+/* Define to `int' if <sys/types.h> doesn't define.  */
+#undef mode_t
+
 /* Define if you don't have <dirent.h>, but have <ndir.h>.  */
 #undef NDIR
 
@@ -172,6 +172,12 @@
 /* Define if your Fortran 77 compiler doesn't accept -c and -o together. */
 #undef F77_NO_MINUS_C_MINUS_O
 
+/* Define to `long' if <sys/types.h> doesn't define.  */
+#undef off_t
+
+/* Define to `int' if <sys/types.h> doesn't define.  */
+#undef pid_t
+
 /* Define if the system does not provide POSIX.1 features except
    with this defined.  */
 #undef _POSIX_1_SOURCE
@@ -199,6 +205,9 @@
    before release 3.  */
 #undef SETVBUF_REVERSED
 
+/* Define to `unsigned' if <sys/types.h> doesn't define.  */
+#undef size_t
+
 /* If using the C implementation of alloca, define if you know the
    direction of stack growth for your system; otherwise it will be
    automatically deduced at run-time.
